@@ -20,7 +20,7 @@ use Perl::Critic::Utils qw(
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = 0.06;
+our $VERSION = '0.07';
 
 #-----------------------------------------------------------------------------
 
@@ -33,6 +33,7 @@ our @EXPORT_OK = qw{
     &get_all_subs_from_list_of_symbols
     &get_package_names_from_include_statements
     &get_package_names_from_package_statements
+    &get_include_statements
     &parse_literal_list
     &parse_quote_words
     &parse_simple_list
@@ -79,10 +80,7 @@ sub parse_quote_words {
 sub get_package_names_from_include_statements {
     my $doc = shift;
 
-    my $statements = $doc->find( \&_wanted_include_statement );
-    return () if not $statements;
-
-    return map { $_->module() } @{$statements};
+    return map { $_->module() } get_include_statements( $doc );
 }
 
 #-----------------------------------------------------------------------------
@@ -98,8 +96,18 @@ sub get_package_names_from_package_statements {
 
 #-----------------------------------------------------------------------------
 
+sub get_include_statements {
+    my $doc = shift;
+
+    my $statements = $doc->find( \&_wanted_include_statement );
+
+    return $statements ? @{$statements} : ();
+}
+
+#-----------------------------------------------------------------------------
+
 sub _wanted_include_statement {
-    my ($doc, $element) = @_;
+    my (undef, $element) = @_;
 
     return 0 if not $element->isa('PPI::Statement::Include');
 
@@ -121,7 +129,7 @@ sub _find_exported_names {
     @export_types = @export_types ?
                     @export_types : qw{@EXPORT @EXPORT_OK};
 
-    my @all_exports = ();
+    my @all_exports;
     for my $export_type( @export_types ) {
 
         my $export_assignment = _find_export_assignment( $doc, $export_type );
@@ -152,7 +160,10 @@ sub find_declared_subroutine_names {
     return if not $sub_nodes;
 
     my @sub_names = map { $_->name() } @{ $sub_nodes };
-    for (@sub_names) { s{\A .*::}{}mxs };  # Remove leading package name
+    for ( @sub_names ) {
+        s{\A .*::}{}mxs;  # Remove leading package name
+    }
+
     return @sub_names;
 }
 
@@ -228,7 +239,7 @@ sub find_declared_constant_names {
 
     my $constant_pragmas_ref = $doc->find( \&_is_constant_pragma );
     return if not $constant_pragmas_ref;
-    my @declared_constants = ();
+    my @declared_constants;
 
     for my $constant_pragma ( @{$constant_pragmas_ref} ) {
 
@@ -300,7 +311,7 @@ sub find_subroutine_calls {
 #-----------------------------------------------------------------------------
 
 sub _is_subroutine_call {
-    my ($doc, $elem) = @_;
+    my (undef, $elem) = @_;
 
     if ( $elem->isa('PPI::Token::Word') ) {
 
@@ -321,7 +332,43 @@ sub _is_subroutine_call {
 #-----------------------------------------------------------------------------
 
 my %functions_that_take_filehandles =
-    hashify( qw(print printf read write sysopen tell open close) );
+    hashify( qw(
+        binmode
+        close
+        eof
+        fileno
+        flock
+        getc
+        open
+        print
+        printf
+        read
+        seek
+        select
+        sysopen
+        sysread
+        sysseek
+        syswrite
+        tell
+        truncate
+        write
+    ) );
+
+
+my %functions_that_take_dirhandles =
+    hashify( qw(
+        closedir
+        opendir
+        readdir
+        rewinddir
+        seekdir
+        telldir
+    ) );
+
+my %functions_that_take_handleish_things = (
+    %functions_that_take_filehandles,
+    %functions_that_take_dirhandles,
+);
 
 sub _smells_like_filehandle {
     my ($elem) = @_;
@@ -334,7 +381,7 @@ sub _smells_like_filehandle {
     # close HANDLE;
 
     if ( my $left_sib = $elem->sprevious_sibling ){
-        return exists $functions_that_take_filehandles{ $left_sib }
+        return exists $functions_that_take_handleish_things{ $left_sib }
           && is_function_call( $left_sib );
     }
 
@@ -356,7 +403,7 @@ sub _smells_like_filehandle {
     return if $enclosing_node->schild(0) != $expression;
 
     if ( my $left_uncle = $enclosing_node->sprevious_sibling ){
-        return exists $functions_that_take_filehandles{ $left_uncle }
+        return exists $functions_that_take_handleish_things{ $left_uncle }
           && is_function_call( $left_uncle );
     }
 
@@ -416,7 +463,7 @@ sub get_all_subs_from_list_of_symbols {
     my @sub_names = grep { m/\A [&\w]/mxs } @symbols;
     for (@sub_names) { s/\A &//mxs; } # Remove optional sigil
 
-    return @sub_names
+    return @sub_names;
 }
 
 #-----------------------------------------------------------------------------
@@ -448,7 +495,7 @@ sub _make_assignment_finder {
 
     my $finder = sub {
 
-        my ($doc, $elem) = @_;
+        my (undef, $elem) = @_;
 
         return 0 if not $elem->isa('PPI::Token::Symbol');
         return 0 if $elem ne $wanted_symbol;
@@ -475,7 +522,7 @@ sub _parse_export_list {
 
 
     # Gather up remaining elements
-    my @left_hand_side = ();
+    my @left_hand_side;
     while ( $snext_sibling = $snext_sibling->snext_sibling() ) {
         push @left_hand_side, $snext_sibling;
     }
@@ -608,6 +655,11 @@ But it does not cover these:
 Returns a list of all the namespaces from all the packages statements
 that appear in the document.
 
+=item C<get_include_statements( $doc )>
+
+Returns a list of PPI::Statement::Include objects that appear in the
+document.
+
 =item C<find_exported_sub_names( $doc, @export_types )>
 
 Returns a list of subroutines which are exported via the specified export
@@ -638,7 +690,7 @@ Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright 2007-2024 Jeffrey Ryan Thalhammer and Andy Lester
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
